/*	
 *	AntilagRelay provides a stable actor to route replicated functions through from client
 *	to server to the firing weapon, so that changes in ownership of the weapon (such as when a pawn dies)
 *	don't interfere	with the replication sequence.  Each Controller gets its own relay.
 *
 *	The relay's delegates must be set to the proper weapon's hit functions (handled by the weapon on firing)
 *
 *		-Mekhazzio 
 */
 
class AntilagRelay extends ReplicationInfo;

var	bool 		bAdvancedBallistics;  //bullets have to find the relay anyway, so may as well get this to them at the same time
var	Controller	Controller;

replication
{
	if ( bNetDirty && bNetOwner && Role==ROLE_Authority )
		Controller, bAdvancedBallistics;
}

reliable server function DoALHit(Actor Target, vector HitLocation, TraceHitInfo HitInfo, optional bool bIsMeleeAttack = false, optional byte ShotPower = 0)
{
	//`ALlog("RELAY:" @ self @ owner @ Controller @  "Performing HitFunction")
	
	HitFunction(Target, HitLocation, HitInfo, bIsMeleeAttack, ShotPower);
}

unreliable server function DoALSegment(ImpactInfo Start, ImpactInfo End, optional Actor Ignore1, optional Actor Ignore2)
{
	//`ALlog("RELAY:" @ self @ owner @ Controller @  "Performing SegmentFunction")
	
	SegmentFunction(Start, End, Ignore1, Ignore2);
}

delegate HitFunction(Actor Target, vector HitLocation, TraceHitInfo HitInfo, optional bool bIsMeleeAttack = false, optional byte ShotPower = 0)
{
	`ALlog("RELAY:" @ self @ owner @ Controller @  "No hit function assigned yet!!")
}

delegate SegmentFunction(ImpactInfo Start, ImpactInfo End, optional Actor Ignore1, optional Actor Ignore2)
{
	`ALlog("RELAY:" @ self @ owner @ Controller @  "No segment function assigned yet!!")
}

event PostBeginPlay()
{
	//`ALlog("RELAY:" @ self @ owner @ Controller @  "New relay spawned!")
	Super.PostBeginPlay();
}

reliable client function ClientSetOwner(PlayerController PC)
{
	//`ALlog("RELAY:" @ self @ owner @ Controller @ "Changing owner!")
	SetOwner(PC);
}

defaultproperties
{
	bOnlyRelevantToOwner=true
	bAlwaysRelevant=false
	bOnlyDirtyReplication=true
}